@@ -22,6 +22,9 @@
 #include <stdbool.h>
 #include <stdlib.h>
 
+#include <cglm/struct.h>
+#include <cglm/version.h>
+
 #include "datatype99.h"
 
 #include "ccan/array_size/array_size.h"
@@ -101,23 +104,72 @@ struct imxpad_t {
 #define IMXPAD(pixel_size_, chip_w_, chip_h_) (struct imxpad_t)		\
         {.square=SQUARE(pixel_size_), .chip_w=chip_w_, .chip_h=chip_h_}
 
+#define CIRPAD_N_IMXPAD_S70 20
+
+#define CIRPAD_PARAMETERS {                                             \
+		{{{0.64907 - 5.0e-3, 0, 0}}, {{glm_rad(90), glm_rad( 0.0000 + 0.012000), 0}}}, \
+		{{{0.64907 - 4.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-6.7400 + 0.010000), 0}}}, \
+		{{{0.64907 - 5.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-13.480 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.1e-3, 0, 0}}, {{glm_rad(90), glm_rad(-20.220 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.6e-3, 0, 0}}, {{glm_rad(90), glm_rad(-26.960 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.3e-3, 0, 0}}, {{glm_rad(90), glm_rad(-33.700 - 0.050000), 0}}}, \
+		{{{0.64907 - 5.5e-3, 0, 0}}, {{glm_rad(90), glm_rad(-40.440 - 0.080000), 0}}}, \
+		{{{0.64907 - 5.8e-3, 0, 0}}, {{glm_rad(90), glm_rad(-47.180 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.6e-3, 0, 0}}, {{glm_rad(90), glm_rad(-53.920 - 0.070000), 0}}}, \
+		{{{0.64907 - 5.8e-3, 0, 0}}, {{glm_rad(90), glm_rad(-60.660 - 0.000000), 0}}}, \
+		{{{0.64907 - 6.2e-3, 0, 0}}, {{glm_rad(90), glm_rad(-67.400 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.5e-3, 0, 0}}, {{glm_rad(90), glm_rad(-74.140 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.5e-3, 0, 0}}, {{glm_rad(90), glm_rad(-80.880 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.7e-3, 0, 0}}, {{glm_rad(90), glm_rad(-87.620 - 0.060000), 0}}}, \
+		{{{0.64907 - 5.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-94.360 - 0.000000), 0}}}, \
+		{{{0.64907 - 5.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-101.10 + 0.050000), 0}}}, \
+		{{{0.64907 - 5.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-107.84 - 0.000000), 0}}}, \
+		{{{0.64907 - 4.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-114.58 - 0.000000), 0}}}, \
+		{{{0.64907 - 4.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-121.32 + 0.010000), 0}}}, \
+		{{{0.64907 - 4.0e-3, 0, 0}}, {{glm_rad(90), glm_rad(-128.06 + 0.010000), 0}}}, \
+			}
+
+struct cirpad_transformation_t {
+         CGLM_ALIGN_MAT vec3s translation;
+         CGLM_ALIGN_MAT vec3s eulers;
+};
+
+struct cirpad_t {
+        struct imxpad_t imxpad_s70;
+        struct shape_t imxpad_s70_shape;
+        size_t n_imxpad_s70;
+        struct cirpad_transformation_t transformations[CIRPAD_N_IMXPAD_S70];
+};
+
+
+#define CIRPAD(pixel_size_, chip_w_, chip_h_) (struct cirpad_t)         \
+        { .imxpad_s70=IMXPAD(pixel_size_, chip_w_, chip_h_)             \
+                        , .imxpad_s70_shape=SHAPE(560, 120)             \
+                        , .n_imxpad_s70=CIRPAD_N_IMXPAD_S70             \
+                        , .transformations=CIRPAD_PARAMETERS		\
+                        }
+
 struct tilling_t {
         struct square_t square;
         int module_width;
         int module_height;
         int gap_width;
         int gap_height;
-        bool fill_gap;
+        bool gap_in_data;
+        bool gap_masked;
+        int border_masked;
 };
 
-#define TILLING(module_width_, module_height_, gap_width_, gap_height_, pixel_size_, fill_gap_) \
+#define TILLING(module_width_, module_height_, gap_width_, gap_height_, pixel_size_, gap_in_data_, gap_masked_, border_masked_) \
         (struct tilling_t){                                             \
                 .square=SQUARE(pixel_size_),                            \
                         .module_width=module_width_,                    \
                         .module_height=module_height_,                  \
                         .gap_width=gap_width_,                          \
                         .gap_height=gap_height_,                        \
-                        .fill_gap=fill_gap_,                            \
+                        .gap_in_data=gap_in_data_,                      \
+                        .gap_masked=gap_masked_,                        \
+                        .border_masked=border_masked_,                  \
                         }
 
 datatype(
@@ -130,7 +182,7 @@ datatype(
         (Merlin, struct square_t),
         (MerlinMedipix3RXQuad, struct tilling_t),
         (MerlinMedipix3RXQuad512, struct tilling_t),
-        (Cirpad, struct square_t)
+        (Cirpad, struct cirpad_t)
         );
 
 struct detector_t {
@@ -152,17 +204,17 @@ static inline struct detector_t get_detector(HklBinocularsDetectorEnum n)
                 DETECTOR(ImXpadS70,
                          SHAPE(560, 120), IMXPAD(130e-6, 80, 120)),
                 DETECTOR(Eiger1M,
-                         SHAPE(1030, 1065), TILLING(1030, 514, 10, 37, 75e-6, true)),
+                         SHAPE(1030, 1065), TILLING(1030, 514, 10, 37, 75e-6, true, true, 0)),
                 DETECTOR(Ufxc,
                          SHAPE(257, 256), SQUARE(75e-6)),
                 DETECTOR(Merlin,
                          SHAPE(256, 256), SQUARE(55e-6)),
                 DETECTOR(MerlinMedipix3RXQuad,
-                         SHAPE(515, 515), TILLING(256, 256, 3, 3, 55e-6, true)),
+                         SHAPE(515, 515), TILLING(256, 256, 3, 3, 55e-6, true, true, 0)),
                 DETECTOR(MerlinMedipix3RXQuad512,
-                         SHAPE(512, 512), TILLING(256, 256, 3, 3, 55e-6, false)),
+                         SHAPE(512, 512), TILLING(256, 256, 3, 3, 55e-6, false, false, 2)),
                 DETECTOR(Cirpad,
-                         SHAPE(560, 2400), SQUARE(130e-6)),
+                         SHAPE(560, 2400), CIRPAD(130e-6, 80, 120)),
         };
 
         if (n > ARRAY_SIZE(detectors))
@@ -244,7 +296,7 @@ static inline double* coordinates_get_tilling(const struct shape_t *shape,
         int i;
         double *arr;
 
-        if (tilling->fill_gap){
+        if (tilling->gap_in_data){
                 arr = coordinates_rectangle(shape,
                                             tilling->square.pixel_size,
                                             tilling->square.pixel_size);
@@ -276,15 +328,17 @@ static inline double* coordinates_get_tilling(const struct shape_t *shape,
         return arr;
 }
 
-static inline double *coordinates_get_imxpad(const struct shape_t *shape,
-                                             const struct imxpad_t *imxpad)
+static inline void coordinates_set_imxpad_xyz(double *y, double *z,
+                                              const struct shape_t *shape,
+                                              const struct imxpad_t *imxpad)
 {
         int i;
-        double *arr = coordinates_new(shape);
-        double *z, *row;
+        double *row;
+
+        /* x = 0 (nothing to do) */
 
         /* y */
-        row = y_coordinates(arr, *shape);
+        row = y;
         for(i=0; i<shape->width; ++i){
                 row[i] = - imxpad_coordinates_pattern(i,
                                                       imxpad->chip_w,
@@ -293,7 +347,6 @@ static inline double *coordinates_get_imxpad(const struct shape_t *shape,
         replicate_row(row, *shape, shape->height);
 
         /* z */
-        z = z_coordinates(arr, *shape);
         for(i=0; i<shape->height; ++i){
                 row = get_row(z, *shape, i);
                 fill_row(row, *shape,
@@ -301,6 +354,57 @@ static inline double *coordinates_get_imxpad(const struct shape_t *shape,
                                                     imxpad->chip_h,
                                                     imxpad->square.pixel_size));
         }
+}
+
+static inline double *coordinates_get_imxpad(const struct shape_t *shape,
+                                             const struct imxpad_t *imxpad)
+{
+        double *arr = coordinates_new(shape);
+
+        double *y = y_coordinates(arr, *shape);
+        double *z = z_coordinates(arr, *shape);
+
+        coordinates_set_imxpad_xyz(y, z, shape, imxpad);
+
+        return arr;
+}
+
+static inline double *coordinates_get_cirpad(const struct shape_t *shape,
+                                             const struct cirpad_t *cirpad)
+{
+        int i;
+        double *arr = coordinates_new(shape);
+        double *x = x_coordinates(arr, *shape);
+        double *y = y_coordinates(arr, *shape);
+        double *z = z_coordinates(arr, *shape);
+
+        for(i=0; i<cirpad->n_imxpad_s70; ++i){
+		size_t j;
+		CGLM_ALIGN_MAT mat4s t_m = GLMS_MAT4_IDENTITY_INIT;
+		CGLM_ALIGN_MAT mat4s r_m = GLMS_MAT4_IDENTITY_INIT;
+                double *x_imxpad = x + i * shape_size(cirpad->imxpad_s70_shape);
+                double *y_imxpad = y + i * shape_size(cirpad->imxpad_s70_shape);
+                double *z_imxpad = z + i * shape_size(cirpad->imxpad_s70_shape);
+
+                /* set the default module coordinates */
+
+                coordinates_set_imxpad_xyz(y_imxpad, z_imxpad,
+                                           &cirpad->imxpad_s70_shape, &cirpad->imxpad_s70);
+
+                /* apply the transformations for each module */
+
+		t_m = glms_translate_make(cirpad->transformations[i].translation);
+		/* glms_mat4_mul(t_m, glms_translate_make(v_t)); */
+		r_m = glms_euler_zyx(cirpad->transformations[i].eulers);
+
+		for(j=0; j<shape_size(cirpad->imxpad_s70_shape); ++j){
+			CGLM_ALIGN_MAT vec3s v = {{x_imxpad[j], y_imxpad[j], z_imxpad[j]}};
+			v = glms_mat4_mulv3(t_m, v, 1);
+			v = glms_mat4_mulv3(r_m, v, 0);
+
+			x_imxpad[j] = v.raw[0], y_imxpad[j] = v.raw[1], z_imxpad[j] = v.raw[2];
+		}
+        }
 
         return arr;
 }
@@ -393,7 +497,8 @@ static inline uint8_t *mask_get_tilling(const struct shape_t *shape,
         uint8_t *arr = no_mask(shape);
 
 
-        if(tilling->fill_gap){
+        /* take care of the gap */
+        if(tilling->gap_in_data && tilling->gap_masked){
                 /* columns */
                 for(i=tilling->module_width;
                     i<shape->width;
@@ -413,6 +518,36 @@ static inline uint8_t *mask_get_tilling(const struct shape_t *shape,
                 }
         }
 
+        /* border */
+        /* TODO deal with the gap */
+        if (tilling->border_masked > 0){
+                /* columns */
+                for(i=0;
+                    i<shape->width;
+                    i = i + tilling->module_width){
+                        uint8_t *col = get_col(arr, i);
+                        fill_column(col, *shape, 1);
+                        replicate_column(col, *shape, tilling->border_masked);
+
+                        col = get_col(arr, i + tilling->module_width - tilling->border_masked);
+                        fill_column(col, *shape, 1);
+                        replicate_column(col, *shape, tilling->border_masked);
+                }
+
+                /* rows */
+                for(i=0;
+                    i<shape->height;
+                    i = i + tilling->module_height){
+                        uint8_t *row = get_row(arr, *shape, i);
+                        fill_row(row, *shape, 1);
+                        replicate_row(row, *shape, tilling->border_masked);
+
+                        row = get_row(arr, *shape, i + tilling->module_height - tilling->border_masked);
+                        fill_row(row, *shape, 1);
+                        replicate_row(row, *shape, tilling->border_masked);
+                }
+        }
+
         return arr;
 }
 
@@ -420,36 +555,30 @@ static inline uint8_t *mask_get_tilling(const struct shape_t *shape,
 /* Calibration */
 /***************/
 
-static inline void translate_coordinates(double *arr,
-                                         const struct shape_t shape,
-                                         double dx, double dy, double dz)
+static inline void translate_coordinates_xyz(double *x, double *y, double *z,
+                                             const struct shape_t *shape,
+                                             double dx, double dy, double dz)
 {
-        double *x = x_coordinates(arr, shape);
-        double *y = y_coordinates(arr, shape);
-        double *z = z_coordinates(arr, shape);
+        size_t i;
 
-        for(int i=0; i<shape_size(shape); ++i){
+        for(i=0; i<shape_size(*shape); ++i){
                 x[i] += dx;
                 y[i] += dy;
                 z[i] += dz;
         }
 }
 
-static inline void rotate_coordinates(double *arr,
-                                      const struct shape_t shape,
-                                      double angle,
-                                      double axis_x, double axis_y, double axis_z)
+static inline void rotate_coordinates_xyz(double *x, double *y, double *z,
+                                          const struct shape_t *shape,
+                                          double angle,
+                                          double axis_x, double axis_y, double axis_z)
 {
-        double *x = x_coordinates(arr, shape);
-        double *y = y_coordinates(arr, shape);
-        double *z = z_coordinates(arr, shape);
-
         HklVector axis = {{axis_x, axis_y, axis_z}};
         HklQuaternion q;
 
         hkl_quaternion_init_from_angle_and_axe(&q, angle, &axis);
 
-        for(int i=0; i<shape_size(shape); ++i){
+        for(int i=0; i<shape_size(*shape); ++i){
                 HklVector v= {{x[i], y[i], z[i]}};
 
                 hkl_vector_rotated_quaternion(&v, &q);
@@ -459,12 +588,9 @@ static inline void rotate_coordinates(double *arr,
         }
 }
 
-static inline void normalize_coordinates(double *arr, const struct shape_t shape)
+static inline void normalize_coordinates_xyz(double *x, double *y, double *z,
+                                             const struct shape_t shape)
 {
-        double *x = x_coordinates(arr, shape);
-        double *y = y_coordinates(arr, shape);
-        double *z = z_coordinates(arr, shape);
-
         for(int i=0; i<shape_size(shape); ++i)
         {
                 double n = sqrt(x[i] * x[i] + y[i] * y[i] + z[i] * z[i]);
@@ -482,7 +608,8 @@ void hkl_binoculars_detector_2d_sixs_calibration(HklBinocularsDetectorEnum n,
                                                  int ix0, int iy0, double sdd,
                                                  double detrot, int normalize_flag)
 {
-        struct shape_t shape = SHAPE(width, height);
+        const struct shape_t shape = SHAPE(width, height);
+        double *x = x_coordinates(arr, shape);
         double *y = y_coordinates(arr, shape);
         double *z = z_coordinates(arr, shape);
 
@@ -490,10 +617,10 @@ void hkl_binoculars_detector_2d_sixs_calibration(HklBinocularsDetectorEnum n,
         double dy = -y[flat_index(shape, ix0, iy0)];
         double dz = -z[flat_index(shape, ix0, iy0)];
 
-        translate_coordinates(arr, shape, dx, dy, dz);
-        rotate_coordinates(arr, shape, detrot, 1, 0, 0);
+        translate_coordinates_xyz(x, y, z, &shape, dx, dy, dz);
+        rotate_coordinates_xyz(x, y, z, &shape, detrot, 1, 0, 0);
         if(normalize_flag)
-                normalize_coordinates(arr, shape);
+                normalize_coordinates_xyz(x, y, z, shape);
 }
 
 /*****************************/
@@ -560,9 +687,9 @@ double *hkl_binoculars_detector_2d_coordinates_get(HklBinocularsDetectorEnum n)
                         arr = coordinates_get_tilling(&detector.shape,
                                                       tilling);
                 }
-                of(Cirpad, square){
-                        arr = coordinates_get_square(&detector.shape,
-                                                     square);
+                of(Cirpad, cirpad){
+                        arr = coordinates_get_cirpad(&detector.shape,
+                                                     cirpad);
                 }
         }
         return arr;
@@ -623,6 +750,9 @@ uint8_t *hkl_binoculars_detector_2d_mask_get(HklBinocularsDetectorEnum n)
                         arr = mask_get_tilling(&detector.shape,
                                                tilling);
                 }
+                of(Cirpad, _){
+                        arr = no_mask(&detector.shape);
+                }
                 otherwise {
                         arr = no_mask(&detector.shape);
                 }
@@ -648,6 +778,20 @@ uint8_t *hkl_binoculars_detector_2d_mask_load(HklBinocularsDetectorEnum n,
         return arr;
 };
 
+uint8_t *hkl_binoculars_detector_2d_mask_or(HklBinocularsDetectorEnum n,
+                                            uint8_t *arr_l, uint8_t *arr_r)
+{
+        size_t i;
+        const struct detector_t detector = get_detector(n);
+        uint8_t *arr = no_mask(&detector.shape);
+
+        if (arr != NULL)
+                for(i=0; i<shape_size(detector.shape); ++i)
+                        arr[i] = arr_l[i] | arr_r[i];
+
+        return arr;
+}
+
 void hkl_binoculars_detector_2d_mask_save(HklBinocularsDetectorEnum n,
                                           const char *fname)
 {
