@@ -9,6 +9,7 @@
 {-# LANGUAGE LambdaCase                 #-}
 {-# LANGUAGE OverloadedStrings          #-}
 {-# LANGUAGE PolyKinds                  #-}
+{-# LANGUAGE ScopedTypeVariables        #-}
 {-# LANGUAGE StandaloneDeriving         #-}
 {-# LANGUAGE TemplateHaskell            #-}
 {-# LANGUAGE TypeApplications           #-}
@@ -55,30 +56,43 @@ module Hkl.Binoculars.Config
     , auto
     , auto'
     , destination'
+    , elemFDef
+    , elemFDef'
+    , elemFMbDef
+    , elemFMbDef'
+    , eitherF
     , files
     , getCapabilities
     , getMask
     , getPreConfig
     , mergeIni
+    , parse'
+    , parseFDef
+    , parseMb
+    , parseMbDef
     , readConfig
     ) where
 
 
 import           Control.Applicative               (many, optional, (<|>))
 import           Control.Lens                      (makeLenses)
-import           Control.Monad.Catch               (MonadThrow, throwM)
+import           Control.Monad.Catch               (MonadCatch, MonadThrow,
+                                                    throwM, try)
 import           Control.Monad.Catch.Pure          (runCatch)
 import           Control.Monad.IO.Class            (MonadIO)
 import           Data.Aeson                        (FromJSON (..), ToJSON (..))
 import           Data.Attoparsec.Text              (Parser, char, decimal,
-                                                    double, parseOnly, satisfy,
-                                                    sepBy, signed, takeText)
+                                                    double, parseOnly, peekChar,
+                                                    satisfy, sepBy, signed,
+                                                    takeText, takeTill)
 import           Data.Either.Combinators           (maybeToRight)
 import           Data.Either.Extra                 (mapLeft, mapRight)
 import           Data.Foldable                     (foldl')
 import           Data.HashMap.Strict               (HashMap, unionWith)
 import           Data.Hashable                     (Hashable)
 import           Data.Ini                          (Ini (..), printIni)
+import           Data.Ini.Config                   (fieldMbOf, parseIniFile,
+                                                    section)
 import           Data.Ini.Config.Bidir             (FieldValue (..), IniSpec,
                                                     bool, field, getIniValue,
                                                     ini, listWithSeparator,
@@ -86,14 +100,14 @@ import           Data.Ini.Config.Bidir             (FieldValue (..), IniSpec,
                                                     text, (.=))
 import           Data.List                         (find, isInfixOf, length)
 import           Data.List.NonEmpty                (NonEmpty (..), map)
-import           Data.Maybe                        (catMaybes)
+import           Data.Maybe                        (catMaybes, fromMaybe)
 import           Data.Text                         (Text, breakOn, cons, drop,
                                                     empty, findIndex,
-                                                    intercalate, length, lines,
-                                                    pack, replace, singleton,
-                                                    strip, take, takeWhile,
-                                                    toLower, unlines, unpack,
-                                                    unwords, isInfixOf)
+                                                    intercalate, isInfixOf,
+                                                    length, lines, pack,
+                                                    replace, singleton, strip,
+                                                    take, takeWhile, toLower,
+                                                    unlines, unpack, unwords)
 import           Data.Text.IO                      (readFile)
 import           Data.Typeable                     (Proxy (..), Typeable,
                                                     typeRep)
@@ -582,19 +596,32 @@ instance Arbitrary Limits where
 
 data MaskLocation = MaskLocation Text
                   | MaskLocation'Tmpl Text
+                  | MaskLocation'Or MaskLocation MaskLocation
     deriving (Eq, Generic, Show)
     deriving anyclass (FromJSON, ToJSON)
 
 instance FieldEmitter MaskLocation where
-  fieldEmitter (MaskLocation t) = t
+  fieldEmitter (MaskLocation t)      = t
   fieldEmitter (MaskLocation'Tmpl t) = t
+  fieldEmitter (MaskLocation'Or l r) = fieldEmitter l <> " | " <> fieldEmitter r
 
 instance FieldParsable MaskLocation where
   fieldParser = do
-    t <- takeText
-    pure $ if "{scannumber:" `Data.Text.isInfixOf` t
-           then MaskLocation'Tmpl t
-           else MaskLocation t
+    let loc :: Text -> MaskLocation
+        loc t = if "{scannumber:" `Data.Text.isInfixOf` t
+                then MaskLocation'Tmpl (strip t)
+                else MaskLocation (strip t)
+
+    t <- takeTill (== '|')
+    if t == ""
+      then fail "MaskLocation is Empty"
+      else do mc <- peekChar
+              case mc of
+                Nothing -> pure $ loc t
+                Just '|'  -> do
+                  _ <- char '|'  -- extract the '|' char
+                  MaskLocation'Or (loc t) <$> fieldParser
+                Just c -> fail ("MaskLocation " <> [c])
 
 instance HasFieldValue MaskLocation where
   fieldvalue = parsable
@@ -912,7 +939,7 @@ binocularsPreConfigDefault = BinocularsPreConfig
 
 binocularsPreConfigSpec :: IniSpec BinocularsPreConfig ()
 binocularsPreConfigSpec = do
-  section "projection" $ do
+  Data.Ini.Config.Bidir.section "projection" $ do
     binocularsPreConfigProjectionType .= field "type" parsable
 
 
@@ -1004,17 +1031,26 @@ files md mr mt =
        then throwM (NoDataFilesUnderTheGivenDirectory dir)
        else return $ catMaybes fs
 
-getMask :: (MonadThrow m, MonadIO m) => Maybe MaskLocation -> Detector Hkl DIM2 -> Scannumber -> m (Maybe Mask)
-getMask ml d (Scannumber i)
-  = case ml of
-      Nothing          -> return Nothing
-      (Just (MaskLocation "default")) -> Just <$> getDetectorDefaultMask d
-      (Just (MaskLocation fname))     -> Just <$> getDetectorMask d fname
-      (Just (MaskLocation'Tmpl tmpl)) -> do
+getMask :: (MonadCatch m, MonadIO m) => MaskLocation -> Detector Hkl DIM2 -> Scannumber -> m Mask
+getMask loc d sn@(Scannumber i)
+  = case loc of
+      MaskLocation "default" -> getDetectorDefaultMask d
+      MaskLocation fname     -> getDetectorMask d fname
+      MaskLocation'Tmpl tmpl -> do
         let tmpl1 = replace "{scannumber:" "%" tmpl
         let tmpl2 = replace "}" "" tmpl1
         let fname = pack $ printf (unpack tmpl2) i
-        Just <$> getDetectorMask d fname
+        getDetectorMask d fname
+      MaskLocation'Or l r -> do
+        el :: Either HklDetectorException Mask <- try $ getMask l d sn
+        case el of
+          Left _ -> getMask r d sn
+          Right ml -> do
+            er :: Either HklDetectorException Mask <- try $ getMask r d sn
+            case er of
+              Left _   -> pure ml
+              Right mr -> maskOr d ml mr
+
 
 getPreConfig' :: ConfigContent -> Either String BinocularsPreConfig
 getPreConfig' (ConfigContent cfg) = do
@@ -1039,3 +1075,73 @@ replace' proj msub i l dtmpl midx = unpack
                                                       Just sub -> fieldEmitter sub
                                                       Nothing -> fieldEmitter proj)
                           . unDestinationTmpl . addOverwrite midx $ dtmpl
+
+
+------------------
+-- Parser utils --
+------------------
+
+parse' :: HasFieldValue b => Text -> Text -> Text -> Either String (Maybe b)
+parse' c s f = parseIniFile c $ Data.Ini.Config.section s (fieldMbOf f auto')
+
+eitherF :: (t1 -> p) -> Either t1 t2 -> (t2 -> p) -> p
+eitherF fa (Left a)  _ = fa a
+eitherF _ (Right b) fb = fb b
+
+parseF :: HasFieldValue b
+       => Text -> Text -> Text -> (Maybe b -> Either String r) -> Either String r
+parseF c s f = eitherF error (parse' c s f)
+
+parseFDef :: HasFieldValue p
+          => Text -> Text -> Text -> p -> Either String p
+parseFDef c s f def = parseF c s f $ \case
+  Nothing -> Right def
+  Just b  -> Right b
+
+parseMb ::  HasFieldValue r
+        => Text -> Text -> Text -> Either String (Maybe r)
+parseMb c s f = eitherF error (parse' c s f) pure
+
+parseMbDef :: HasFieldValue r
+           => Text -> Text -> Text -> Maybe r -> Maybe r
+parseMbDef c s f def = eitherF error (parse' c s f) (<|> def)
+
+elemFDef' :: HasFieldComment w => Text -> (v -> w) -> v -> v -> [(Text, Text)]
+elemFDef' k f v d = elemFDef k f v d (fieldComment (f v))
+
+
+elemContent :: Text -> Text -> [Text] -> [Text]
+elemContent k def cs =
+  [ ""
+  , k <> ":"
+  , ""
+  ]
+  <> cs
+  <> [ ""
+     , "default value: `" <> def <> "`"
+     , ""
+     , "uncomment and edit the next line if you want to modify the value"
+     ]
+
+elemFDef ::  HasFieldValue w => Text -> (v -> w) -> v -> v -> [Text] -> [(Text, Text)]
+elemFDef k f v d cs = [ ("#", l) | l <- ls ] <> [(k,  fvEmit fieldvalue (f v))]
+  where
+    ls :: [Text]
+    ls = elemContent k defv cs
+
+    defv :: Text
+    defv = fvEmit fieldvalue (f d)
+
+elemFMbDef' ::  HasFieldComment w => Text -> (v -> Maybe w) -> v -> v -> [(Text, Text)]
+elemFMbDef' k f v d = elemFMbDef k f v d (fieldComment (fromMaybe undefined (f v)))
+
+elemFMbDef ::  HasFieldValue w => Text -> (v -> Maybe w) -> v -> v -> [Text] -> [(Text, Text)]
+elemFMbDef k f v d cs = [ ("#", l) | l <- ls ] <> maybe [("# " <> k, "")] (\w -> [(k, fvEmit fieldvalue w)]) (f v)
+  where
+    ls :: [Text]
+    ls = elemContent k defv cs
+
+    defv :: Text
+    defv = case f d of
+             Nothing -> "<not set>"
+             Just w  -> fvEmit fieldvalue w
