@@ -57,7 +57,6 @@ import           Pipes.Safe                        (MonadSafe, catch, throwM)
 import           Prelude                           hiding (filter)
 
 import           Hkl.Binoculars.Config
-import           Hkl.Binoculars.Config.Common
 import           Hkl.Detector
 import           Hkl.Exception
 import           Hkl.Geometry
@@ -74,6 +73,8 @@ import           Hkl.Types
 class Is0DStreamable a e where
   extract0DStreamValue :: a -> IO e
 
+-- Is0DStreamable (instances)
+
 instance Is0DStreamable Dataset CDouble where
   extract0DStreamValue d = getPosition d 0
 
@@ -393,15 +394,8 @@ instance DataSource Mask where
 
     withDataSourceP _ DataSourcePath'Mask'NoMask g = g DataSourceAcq'Mask'NoMask
     withDataSourceP (ScanFile _ sn)  (DataSourcePath'Mask l d) g
-        = do  mm <- getMask (Just l) d sn
-              case mm of
-                Nothing  -> g DataSourceAcq'Mask'NoMask
-                (Just m) -> g (DataSourceAcq'Mask m)
-
-
-              --       withForeignPtr (toForeignPtr m) $ \ptr -> f ptr
-
-              -- g (DataSourceAcq'Mask mm)
+        = do  m <- getMask l d sn
+              g (DataSourceAcq'Mask m)
 
 -- Scannumber
 
