@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2018 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019, 2022 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  * Copyright (C) 2017      DESY
@@ -625,7 +625,7 @@ HklEngine *hkl_engine_lisa_pm_new(HklEngineList *engines)
 		.free=hkl_engine_lisapm_free_real,
 	};
 
-	self = HKL_MALLOC(HklEngineLisaPM);
+	self = g_new(HklEngineLisaPM, 1);
 
 	hkl_engine_init(&self->engine, &info, &operations, engines);
 	self->sth = register_pseudo_axis(&self->engine, engines, &sth);
