@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2019, 2021, 2022 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019, 2021, 2022, 2023 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -408,7 +408,10 @@ static inline void hkl_engine_init(HklEngine *self,
 
 static inline HklParameter *register_mode_parameter(HklMode *mode, unsigned int index)
 {
-	return darray_item(mode->parameters, index);
+        if(index < darray_size(mode->parameters))
+                return darray_item(mode->parameters, index);
+        else
+                abort();
 }
 
 static inline HklParameter *register_pseudo_axis(HklEngine *self,
