@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2019, 2022 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019, 2022, 2023 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -26,6 +26,13 @@
 #include "hkl-unit-private.h"           // for HklUnit, etc
 #include "hkl.h"                        // for FALSE, HKL_DEGTORAD, etc
 
+const HklUnit hkl_unit_angle_deg = {HklDPlaneAngle, M_PI/180., "Degree", "°"};
+const HklUnit hkl_unit_angle_rad = {HklDPlaneAngle, 1., "Radian", "rad"};
+const HklUnit hkl_unit_length_nm = {HklDLength, 1e-9, "Nano Meter", "nm"};
+const HklUnit hkl_unit_angle_mrad = {HklDPlaneAngle, 1e-3, "Milli Radian", "mrad"};
+const HklUnit hkl_unit_length_mm = {HklDLength, 1e-3, "Milli Meter", "mm"};
+const HklUnit hkl_unit_length_meter = {HklDLength, 1., "Meter", "m"};
+
 /**
  * hkl_unit_dup: (skip)
  * @self:
