@@ -472,14 +472,15 @@ static void hkl_projection(void)
                                     {30, 30, 30, 30}};
 
         /* the expected result for the three axes of the 1st detector */
-        static ptrdiff_t imin[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{-14, -2, 0},
-                                                                           {-14, -2, 0},
-                                                                           {-14, -2, 0},
-                                                                           {-14, -2, -2},
+        static ptrdiff_t imin[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{-14,-2, 0},
+                                                                           {-14,-2, 0},
+                                                                           {-14,-2, 0},
+                                                                           {-14,-2,-2},
                                                                            {-13, 0, 0},
                                                                            {-13, 0, 0},
-                                                                           {-13, -1, 0},
-                                                                           {-13, -1, 0}};
+                                                                           {-13,-1, 0},
+                                                                           {-13,-1, 0},
+                                                                           {-18, 0,-1}};
 
         static ptrdiff_t imax[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{1, 34, 15},
                                                                            {1, 34, 19},
@@ -488,7 +489,8 @@ static void hkl_projection(void)
                                                                            {0, 33, 15},
                                                                            {0, 33, 15},
                                                                            {0, 33, 15},
-                                                                           {0, 33, 15}};
+                                                                           {0, 33, 15},
+                                                                           {0, 33, 36}};
 
         for(n=0; n<HKL_BINOCULARS_DETECTOR_NUM_DETECTORS; ++n){
                 size_t i;
@@ -551,6 +553,11 @@ static void hkl_projection(void)
                         res &= imax[n][i] == darray_item(cube->axes, i).imax;
                 }
 
+                if (res == FALSE){
+                        fprintf(stdout, "\n");
+                        hkl_binoculars_cube_fprintf(stdout, cube);
+                }
+
                 free(mask);
                 free(pixels_coordinates);
                 hkl_binoculars_cube_free(cube);
@@ -594,14 +601,15 @@ static void test_projection(void)
                                     {30, 30, 30, 30}};
 
         /* the expected result for the three axes of the 1st detector */
-        static ptrdiff_t imin[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{-14, -2, 0},
-                                                                           {-14, -2, 0},
-                                                                           {-14, -2, 0},
-                                                                           {-14, -2, -2},
+        static ptrdiff_t imin[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{-14,-2, 0},
+                                                                           {-14,-2, 0},
+                                                                           {-14,-2, 0},
+                                                                           {-14,-2,-2},
                                                                            {-13, 0, 0},
                                                                            {-13, 0, 0},
-                                                                           {-13, -1, 0},
-                                                                           {-13, -1, 0}};
+                                                                           {-13,-1, 0},
+                                                                           {-13,-1, 0},
+									   {-18, 0,-1}};
 
         static ptrdiff_t imax[HKL_BINOCULARS_DETECTOR_NUM_DETECTORS][3] = {{1, 34, 15},
                                                                            {1, 34, 19},
@@ -610,7 +618,8 @@ static void test_projection(void)
                                                                            {0, 33, 15},
                                                                            {0, 33, 15},
                                                                            {0, 33, 15},
-                                                                           {0, 33, 15}};
+                                                                           {0, 33, 15},
+                                                                           {0, 33, 36}};
 
         for(n=0; n<HKL_BINOCULARS_DETECTOR_NUM_DETECTORS; ++n){
                 size_t i;
@@ -699,6 +708,12 @@ static void test_projection(void)
                         res &= DIAG(imax[n][i] == darray_item(cube2->axes, i).imax);
                 }
 
+                if (res == FALSE){
+                        fprintf(stdout, "\n");
+                        hkl_binoculars_cube_fprintf(stdout, cube);
+                }
+
+
                 free(mask);
                 free(pixels_coordinates_2);
                 free(pixels_coordinates);
